﻿using System;
using System.Collections;
using System.Drawing;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace ThreeWaySort
{
    partial class Form1
    {
        /// <summary>
        /// Required designer variable.
        /// </summary>
        private System.ComponentModel.IContainer components = null;

        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        /// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null)) {
                components.Dispose();
            }
            base.Dispose(disposing);
        }


        private class MySortComparer : IComparer
        {
            internal MySortComparer()
            {
            }

            int IComparer.Compare(object x, object y)
            {
                UltraGridCell xCell = (UltraGridCell) x;
                UltraGridCell yCell = (UltraGridCell) y;

                double text1 = Double.Parse(xCell.Value.ToString());
                double text2 = Double.Parse(yCell.Value.ToString());

                //
                // Absolute descending
                //
                return (Int32) (Math.Abs(text1) - Math.Abs(text2));

            }
        }

        private void ultraGrid_BeforeSortChange(object sender, Infragistics.Win.UltraWinGrid.BeforeSortChangeEventArgs e)
        {
            if (e.SortedColumns.Count == 0) {
                return;
            }

            if (!(e.SortedColumns[0].Key.Equals("Column2")) || !(e.SortedColumns[0].Key.Equals("Column3"))) {
                return;
            }
            UltraGridColumn column = e.SortedColumns[0];
            SortIndicator indicator = column.SortIndicator;
            if (indicator == SortIndicator.Ascending) {
                MySortComparer sortComparer = new MySortComparer();
                column.SortComparer = sortComparer;
            }
            else if (indicator == SortIndicator.Descending) {
                Console.WriteLine("going from ascending ");
            }
            else {
                column.SortComparisonType = SortComparisonType.Default;
                column.SortIndicator = SortIndicator.Ascending;
            }
        }

        /// <summary>
        /// When used a DrawFilter for an UltraWinGrid, this class displayed numbers in the upper
        /// right corner of the colmn header to indicate the order of sorted columns. 
        /// </summary>
        public class Sort_Order_Indicator_DrawFilter : IUIElementDrawFilter
        {
            #region IUIElementDrawFilter Members

            bool IUIElementDrawFilter.DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
            {
                if (drawPhase == DrawPhase.AfterDrawElement) {

                    HeaderUIElement headerUIElement = drawParams.Element as HeaderUIElement;
                    if (headerUIElement != null) {

                        UltraGridColumn column = drawParams.Element.GetContext(typeof(UltraGridColumn)) as UltraGridColumn;
                        if (column.SortIndicator == SortIndicator.Descending) {
                            column.SortIndicator = SortIndicator.None;
                        }
                        else {
                            column.SortIndicator = SortIndicator.Descending;
                        }

                        using (Font font = new Font("Arial", 14)) {

                            using (SolidBrush solidBrush = new SolidBrush(Color.Black)) {

                                StringFormat stringFormat = new StringFormat();
                                stringFormat.Alignment = StringAlignment.Far;
                                stringFormat.LineAlignment = StringAlignment.Near;

                                DrawStringParameters drawStringParameters = new DrawStringParameters(
                                    drawParams.Graphics,
                                    "+",
                                    font,
                                    solidBrush,
                                    headerUIElement.Rect,
                                    stringFormat,
                                    GdiDrawStringFlags.GDIPlus,
                                    TextOrientationInfo.Horizontal);

                                // Draw the string. 
                                DrawUtility.DrawString(ref drawStringParameters);
                            }
                        }
                    }
                    else
                        Console.WriteLine("Got into DrawElement for an element that is not a HeaderUIElement. Unexpected.");
                }
                else
                    Console.WriteLine("Got into DrawElement for a phase other than AfterDrawElement. Unexpected.");

                return false;
            }

            DrawPhase IUIElementDrawFilter.GetPhasesToFilter(ref UIElementDrawParams drawParams)
            {
                // Trap for a HeaderUIElement
                if (drawParams.Element is HeaderUIElement) {
                    // Get the column. 
                    UltraGridColumn column = drawParams.Element.GetContext(typeof(UltraGridColumn)) as UltraGridColumn;

                    // Make sure there actually is a column. The HeaderUIElement might represent a 
                    // Group header, for instance, in which case we don't want to do anything. 
                    // Also, there's no reason to bother drawing anything unless the column is sorted.
                    if (column != null &&
                        (column.SortIndicator == SortIndicator.Ascending || column.SortIndicator == SortIndicator.Descending
                        || column.SortIndicator == SortIndicator.None)) {
                        // If we get to this point, we know we are dealing with a column header for
                        // a column that is sorted. So fire off the AfterDrawElement so we can draw
                        // onto the header after it's done with it's normal drawing. 
                        return DrawPhase.AfterDrawElement;
                    }
                }

                // Do nothing. 
                return DrawPhase.None;
            }

            #endregion

        }

        #region Windows Form Designer generated code

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            this.components = new System.ComponentModel.Container();
            Infragistics.Win.Appearance appearance1 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinGrid.UltraGridBand ultraGridBand1 = new Infragistics.Win.UltraWinGrid.UltraGridBand("Band 0", -1);
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn1 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column1");
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn2 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column2", -1, null, 0, Infragistics.Win.UltraWinGrid.SortIndicator.Ascending, false);
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn3 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column3");
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn4 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column4");
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn5 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column5");
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn6 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column6");
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn7 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column7");
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn8 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column8");
            Infragistics.Win.UltraWinGrid.UltraGridColumn ultraGridColumn9 = new Infragistics.Win.UltraWinGrid.UltraGridColumn("Column9");
            Infragistics.Win.Appearance appearance2 = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance appearance3 = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance appearance4 = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance appearance5 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn1 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column1");
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn2 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column2");
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn3 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column3");
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn4 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column4");
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn5 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column5");
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn6 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column6");
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn7 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column7");
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn8 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column8");
            Infragistics.Win.UltraWinDataSource.UltraDataColumn ultraDataColumn9 = new Infragistics.Win.UltraWinDataSource.UltraDataColumn("Column9");
            this.ultraGrid = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.ultraDataSource1 = new Infragistics.Win.UltraWinDataSource.UltraDataSource(this.components);
            this.ultraDataSource = new Infragistics.Win.UltraWinDataSource.UltraDataSource(this.components);
            ((System.ComponentModel.ISupportInitialize) (this.ultraGrid)).BeginInit();
            ((System.ComponentModel.ISupportInitialize) (this.ultraDataSource1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize) (this.ultraDataSource)).BeginInit();
            this.SuspendLayout();
            // 
            // ultraGrid
            // 
            this.ultraGrid.DataSource = this.ultraDataSource1;
            appearance1.BackColor = System.Drawing.Color.White;
            this.ultraGrid.DisplayLayout.Appearance = appearance1;
            ultraGridBand1.Columns.AddRange(new object[] {
            ultraGridColumn1,
            ultraGridColumn2,
            ultraGridColumn3,
            ultraGridColumn4,
            ultraGridColumn5,
            ultraGridColumn6,
            ultraGridColumn7,
            ultraGridColumn8,
            ultraGridColumn9});
            this.ultraGrid.DisplayLayout.BandsSerializer.Add(ultraGridBand1);
            this.ultraGrid.DisplayLayout.Override.AllowAddNew = Infragistics.Win.UltraWinGrid.AllowAddNew.No;
            this.ultraGrid.DisplayLayout.Override.AllowDelete = Infragistics.Win.DefaultableBoolean.False;
            this.ultraGrid.DisplayLayout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            this.ultraGrid.DisplayLayout.Override.AllowUpdate = Infragistics.Win.DefaultableBoolean.False;
            appearance2.BackColor = System.Drawing.Color.Transparent;
            this.ultraGrid.DisplayLayout.Override.CardAreaAppearance = appearance2;
            this.ultraGrid.DisplayLayout.Override.FilterClearButtonLocation = Infragistics.Win.UltraWinGrid.FilterClearButtonLocation.Cell;
            this.ultraGrid.DisplayLayout.Override.FilterOperandStyle = Infragistics.Win.UltraWinGrid.FilterOperandStyle.DropDownList;
            this.ultraGrid.DisplayLayout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.HeaderIcons;
            appearance3.BackColor = System.Drawing.Color.FromArgb(((int) (((byte) (89)))), ((int) (((byte) (135)))), ((int) (((byte) (214)))));
            appearance3.BackColor2 = System.Drawing.Color.FromArgb(((int) (((byte) (7)))), ((int) (((byte) (59)))), ((int) (((byte) (150)))));
            appearance3.BackGradientStyle = Infragistics.Win.GradientStyle.Vertical;
            appearance3.FontData.BoldAsString = "True";
            appearance3.FontData.Name = "Arial";
            appearance3.FontData.SizeInPoints = 10F;
            appearance3.ForeColor = System.Drawing.Color.White;
            appearance3.ThemedElementAlpha = Infragistics.Win.Alpha.Transparent;
            this.ultraGrid.DisplayLayout.Override.HeaderAppearance = appearance3;
            this.ultraGrid.DisplayLayout.Override.HeaderClickAction = Infragistics.Win.UltraWinGrid.HeaderClickAction.SortSingle;
            this.ultraGrid.DisplayLayout.Override.RowFilterAction = Infragistics.Win.UltraWinGrid.RowFilterAction.HideFilteredOutRows;
            this.ultraGrid.DisplayLayout.Override.RowFilterMode = Infragistics.Win.UltraWinGrid.RowFilterMode.AllRowsInBand;
            appearance4.BackColor = System.Drawing.Color.FromArgb(((int) (((byte) (89)))), ((int) (((byte) (135)))), ((int) (((byte) (214)))));
            appearance4.BackColor2 = System.Drawing.Color.FromArgb(((int) (((byte) (7)))), ((int) (((byte) (59)))), ((int) (((byte) (150)))));
            appearance4.BackGradientStyle = Infragistics.Win.GradientStyle.Vertical;
            this.ultraGrid.DisplayLayout.Override.RowSelectorAppearance = appearance4;
            this.ultraGrid.DisplayLayout.Override.RowSelectors = Infragistics.Win.DefaultableBoolean.True;
            appearance5.BackColor = System.Drawing.Color.FromArgb(((int) (((byte) (251)))), ((int) (((byte) (230)))), ((int) (((byte) (148)))));
            appearance5.BackColor2 = System.Drawing.Color.FromArgb(((int) (((byte) (238)))), ((int) (((byte) (149)))), ((int) (((byte) (21)))));
            appearance5.BackGradientStyle = Infragistics.Win.GradientStyle.Vertical;
            this.ultraGrid.DisplayLayout.Override.SelectedRowAppearance = appearance5;
            this.ultraGrid.DisplayLayout.Override.SelectTypeCell = Infragistics.Win.UltraWinGrid.SelectType.None;
            this.ultraGrid.DisplayLayout.Override.SelectTypeCol = Infragistics.Win.UltraWinGrid.SelectType.None;
            this.ultraGrid.DisplayLayout.Override.SelectTypeRow = Infragistics.Win.UltraWinGrid.SelectType.Single;
            this.ultraGrid.DisplayLayout.ScrollBounds = Infragistics.Win.UltraWinGrid.ScrollBounds.ScrollToFill;
            this.ultraGrid.DisplayLayout.ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle.Immediate;
            this.ultraGrid.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte) (0)));
            this.ultraGrid.Location = new System.Drawing.Point(0, 150);
            this.ultraGrid.Name = "ultraGrid";
            this.ultraGrid.Size = new System.Drawing.Size(803, 279);
            this.ultraGrid.TabIndex = 0;
            this.ultraGrid.BeforeSortChange += new Infragistics.Win.UltraWinGrid.BeforeSortChangeEventHandler(this.ultraGrid_BeforeSortChange);
            this.ultraGrid.DrawFilter = new Sort_Order_Indicator_DrawFilter();
            // 
            // ultraDataSource1
            // 
            ultraDataColumn2.DataType = typeof(double);
            ultraDataColumn3.DataType = typeof(double);
            ultraDataColumn4.DataType = typeof(double);
            ultraDataColumn5.DataType = typeof(double);
            ultraDataColumn6.DataType = typeof(int);
            ultraDataColumn7.DataType = typeof(int);
            ultraDataColumn8.DataType = typeof(int);
            ultraDataColumn9.DataType = typeof(double);
            this.ultraDataSource1.Band.Columns.AddRange(new object[] {
            ultraDataColumn1,
            ultraDataColumn2,
            ultraDataColumn3,
            ultraDataColumn4,
            ultraDataColumn5,
            ultraDataColumn6,
            ultraDataColumn7,
            ultraDataColumn8,
            ultraDataColumn9});
            // 
            // Form1
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.ClientSize = new System.Drawing.Size(815, 527);
            this.Controls.Add(this.ultraGrid);
            this.Name = "Form1";
            this.Text = "UltraGridForm";
            ((System.ComponentModel.ISupportInitialize) (this.ultraGrid)).EndInit();
            ((System.ComponentModel.ISupportInitialize) (this.ultraDataSource1)).EndInit();
            ((System.ComponentModel.ISupportInitialize) (this.ultraDataSource)).EndInit();
            this.ResumeLayout(false);

        }

        #endregion

        private Infragistics.Win.UltraWinGrid.UltraGrid ultraGrid;
        private Infragistics.Win.UltraWinDataSource.UltraDataSource ultraDataSource;
        private Infragistics.Win.UltraWinDataSource.UltraDataSource ultraDataSource1;
    }
}